library dinner.soup;

import 'package:angular2/metadata.dart';

@Component(selector: '[soup]')
class OnChangeSoupComponent implements OnChanges {}

@Component(selector: '[soup]')
class OnDestroySoupComponent implements OnDestroy {}

@Component(selector: '[soup]')
class OnCheckSoupComponent implements DoCheck {}

@Component(selector: '[soup]')
class OnInitSoupComponent implements OnInit {}

@Component(selector: '[soup]')
class AfterContentInitSoupComponent implements AfterContentInit {}

@Component(selector: '[soup]')
class AfterContentCheckedSoupComponent implements AfterContentChecked {}

@Component(selector: '[soup]')
class AfterViewInitSoupComponent implements AfterViewInit {}

@Component(selector: '[soup]')
class AfterViewCheckedSoupComponent implements AfterViewChecked {}